@@ -41,7 +41,7 @@ use Carp;
 @ISA = qw(Exporter DBI::Shell::Std);
 @EXPORT = qw(shell);
 
-$VERSION = '11.95_02';
+$VERSION = '11.95_03';
 
 my $warning = <<'EOM';
 
@@ -415,7 +415,7 @@ sub default_term {
     # Setup Term
     #
     my $mode;
-    if (is_interactive()) {
+    if (!is_interactive()) {
 		$sh->{batch} = 1;
 		$mode = "in batch mode";
     } else {
